@@ -28,6 +28,8 @@ pub mod cloudiot_device_request;
 pub use self::cloudiot_device_request::CloudiotDeviceRequest;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
+pub mod config_type_enum;
+pub use self::config_type_enum::ConfigTypeEnum;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
 pub mod device;
@@ -54,14 +56,10 @@ pub mod experiment_device_config;
 pub use self::experiment_device_config::ExperimentDeviceConfig;
 pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
-pub mod janus_cloud_auth;
-pub use self::janus_cloud_auth::JanusCloudAuth;
-pub mod janus_cloud_auth_request;
-pub use self::janus_cloud_auth_request::JanusCloudAuthRequest;
-pub mod janus_edge_auth;
-pub use self::janus_edge_auth::JanusEdgeAuth;
-pub mod janus_edge_auth_request;
-pub use self::janus_edge_auth_request::JanusEdgeAuthRequest;
+pub mod janus_auth;
+pub use self::janus_auth::JanusAuth;
+pub mod janus_auth_request;
+pub use self::janus_auth_request::JanusAuthRequest;
 pub mod janus_task;
 pub use self::janus_task::JanusTask;
 pub mod janus_task_request;
@@ -152,10 +150,8 @@ pub mod paginated_experiment_list;
 pub use self::paginated_experiment_list::PaginatedExperimentList;
 pub mod paginated_gcode_file_list;
 pub use self::paginated_gcode_file_list::PaginatedGcodeFileList;
-pub mod paginated_janus_cloud_auth_list;
-pub use self::paginated_janus_cloud_auth_list::PaginatedJanusCloudAuthList;
-pub mod paginated_janus_edge_auth_list;
-pub use self::paginated_janus_edge_auth_list::PaginatedJanusEdgeAuthList;
+pub mod paginated_janus_auth_list;
+pub use self::paginated_janus_auth_list::PaginatedJanusAuthList;
 pub mod paginated_model_artifact_list;
 pub use self::paginated_model_artifact_list::PaginatedModelArtifactList;
 pub mod paginated_octo_print_backup_list;
@@ -206,8 +202,6 @@ pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
 pub mod patched_device_request;
 pub use self::patched_device_request::PatchedDeviceRequest;
-pub mod patched_janus_edge_auth_request;
-pub use self::patched_janus_edge_auth_request::PatchedJanusEdgeAuthRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_polymorphic_event_request;
